@@ -1,4 +1,12 @@
-"Main interface for stepfunctions service type defs"
+"""
+Main interface for stepfunctions service type definitions.
+
+Usage::
+
+    from mypy_boto3.stepfunctions.type_defs import CreateActivityOutputTypeDef
+
+    data: CreateActivityOutputTypeDef = {...}
+"""
 from datetime import datetime
 import sys
 from typing import List
@@ -13,6 +21,62 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "CreateActivityOutputTypeDef",
+    "CreateStateMachineOutputTypeDef",
+    "DescribeActivityOutputTypeDef",
+    "DescribeExecutionOutputTypeDef",
+    "CloudWatchLogsLogGroupTypeDef",
+    "LogDestinationTypeDef",
+    "LoggingConfigurationTypeDef",
+    "DescribeStateMachineForExecutionOutputTypeDef",
+    "DescribeStateMachineOutputTypeDef",
+    "GetActivityTaskOutputTypeDef",
+    "ActivityFailedEventDetailsTypeDef",
+    "ActivityScheduleFailedEventDetailsTypeDef",
+    "ActivityScheduledEventDetailsTypeDef",
+    "ActivityStartedEventDetailsTypeDef",
+    "ActivitySucceededEventDetailsTypeDef",
+    "ActivityTimedOutEventDetailsTypeDef",
+    "ExecutionAbortedEventDetailsTypeDef",
+    "ExecutionFailedEventDetailsTypeDef",
+    "ExecutionStartedEventDetailsTypeDef",
+    "ExecutionSucceededEventDetailsTypeDef",
+    "ExecutionTimedOutEventDetailsTypeDef",
+    "LambdaFunctionFailedEventDetailsTypeDef",
+    "LambdaFunctionScheduleFailedEventDetailsTypeDef",
+    "LambdaFunctionScheduledEventDetailsTypeDef",
+    "LambdaFunctionStartFailedEventDetailsTypeDef",
+    "LambdaFunctionSucceededEventDetailsTypeDef",
+    "LambdaFunctionTimedOutEventDetailsTypeDef",
+    "MapIterationEventDetailsTypeDef",
+    "MapStateStartedEventDetailsTypeDef",
+    "StateEnteredEventDetailsTypeDef",
+    "StateExitedEventDetailsTypeDef",
+    "TaskFailedEventDetailsTypeDef",
+    "TaskScheduledEventDetailsTypeDef",
+    "TaskStartFailedEventDetailsTypeDef",
+    "TaskStartedEventDetailsTypeDef",
+    "TaskSubmitFailedEventDetailsTypeDef",
+    "TaskSubmittedEventDetailsTypeDef",
+    "TaskSucceededEventDetailsTypeDef",
+    "TaskTimedOutEventDetailsTypeDef",
+    "HistoryEventTypeDef",
+    "GetExecutionHistoryOutputTypeDef",
+    "ActivityListItemTypeDef",
+    "ListActivitiesOutputTypeDef",
+    "ExecutionListItemTypeDef",
+    "ListExecutionsOutputTypeDef",
+    "StateMachineListItemTypeDef",
+    "ListStateMachinesOutputTypeDef",
+    "TagTypeDef",
+    "ListTagsForResourceOutputTypeDef",
+    "PaginatorConfigTypeDef",
+    "StartExecutionOutputTypeDef",
+    "StopExecutionOutputTypeDef",
+    "UpdateStateMachineOutputTypeDef",
+)
+
 CreateActivityOutputTypeDef = TypedDict(
     "CreateActivityOutputTypeDef", {"activityArn": str, "creationDate": datetime}
 )
@@ -48,17 +112,6 @@ class DescribeExecutionOutputTypeDef(
     pass
 
 
-DescribeStateMachineForExecutionOutputTypeDef = TypedDict(
-    "DescribeStateMachineForExecutionOutputTypeDef",
-    {
-        "stateMachineArn": str,
-        "name": str,
-        "definition": str,
-        "roleArn": str,
-        "updateDate": datetime,
-    },
-)
-
 CloudWatchLogsLogGroupTypeDef = TypedDict(
     "CloudWatchLogsLogGroupTypeDef", {"logGroupArn": str}, total=False
 )
@@ -77,6 +130,30 @@ LoggingConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredDescribeStateMachineForExecutionOutputTypeDef = TypedDict(
+    "_RequiredDescribeStateMachineForExecutionOutputTypeDef",
+    {
+        "stateMachineArn": str,
+        "name": str,
+        "definition": str,
+        "roleArn": str,
+        "updateDate": datetime,
+    },
+)
+_OptionalDescribeStateMachineForExecutionOutputTypeDef = TypedDict(
+    "_OptionalDescribeStateMachineForExecutionOutputTypeDef",
+    {"loggingConfiguration": LoggingConfigurationTypeDef},
+    total=False,
+)
+
+
+class DescribeStateMachineForExecutionOutputTypeDef(
+    _RequiredDescribeStateMachineForExecutionOutputTypeDef,
+    _OptionalDescribeStateMachineForExecutionOutputTypeDef,
+):
+    pass
+
+
 _RequiredDescribeStateMachineOutputTypeDef = TypedDict(
     "_RequiredDescribeStateMachineOutputTypeDef",
     {
